DESCRIPTION = "A simple serverless function transformer,\
        and a simple way to call function in other language."

DEFAULT_PORT = 23330
ALIVE_SYMBOL = {
    "python": "\"PYTHON_GLOBAL_CALL_ALIVE\""
}

OK_STATUS = "OK"
